aboutsummaryrefslogtreecommitdiff
path: root/apps/commander/state_machine_helper.h
diff options
context:
space:
mode:
authorLorenz Meier <lm@inf.ethz.ch>2012-12-31 00:41:11 +0100
committerLorenz Meier <lm@inf.ethz.ch>2012-12-31 00:41:11 +0100
commit7972a56076058331e43a8a1e06c3b2c87e833bce (patch)
treeb0ee953ec808131ab60d90a252a160c2a8fc07fa /apps/commander/state_machine_helper.h
parent1b82dbb58db9b7a279841714fe64c7830f71e290 (diff)
downloadpx4-firmware-7972a56076058331e43a8a1e06c3b2c87e833bce.tar.gz
px4-firmware-7972a56076058331e43a8a1e06c3b2c87e833bce.tar.bz2
px4-firmware-7972a56076058331e43a8a1e06c3b2c87e833bce.zip
State machine / switching improvements
Diffstat (limited to 'apps/commander/state_machine_helper.h')
-rw-r--r--apps/commander/state_machine_helper.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/apps/commander/state_machine_helper.h b/apps/commander/state_machine_helper.h
index 815645089..2f2ccc729 100644
--- a/apps/commander/state_machine_helper.h
+++ b/apps/commander/state_machine_helper.h
@@ -128,13 +128,13 @@ void update_state_machine_mode_manual(int status_pub, struct vehicle_status_s *c
void update_state_machine_mode_stabilized(int status_pub, struct vehicle_status_s *current_status, const int mavlink_fd);
/**
* Handle state machine if mode switch is hold
*
* @param status_pub file descriptor for state update topic publication
* @param current_status pointer to the current state machine to operate on
* @param mavlink_fd file descriptor for MAVLink statustext messages
*/
-void update_state_machine_mode_hold(int status_pub, struct vehicle_status_s *current_status, const int mavlink_fd);
+void update_state_machine_mode_guided(int status_pub, struct vehicle_status_s *current_status, const int mavlink_fd);
/**
* Handle state machine if mode switch is auto
@@ -128,13 +128,13 @@ void update_state_machine_mode_manual(int status_pub, struct vehicle_status_s *c
void update_state_machine_mode_stabilized(int status_pub, struct vehicle_status_s *current_status, const int mavlink_fd);
/**
- * Handle state machine if mode switch is hold
+ * Handle state machine if mode switch is guided
*
* @param status_pub file descriptor for state update topic publication